@@ -30,7 +30,7 @@ use Alien::Base::ModuleBuild::Repository::FTP;
 use Alien::Base::ModuleBuild::Repository::Local;
 
 # ABSTRACT: A Module::Build subclass for building Alien:: modules and their libraries
-our $VERSION = '1.09_01'; # TRIAL VERSION
+our $VERSION = '1.16_01'; # TRIAL VERSION
 $VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 # setup protocol specific classes
@@ -360,6 +360,8 @@ sub ACTION_code {
     open my $fh, '>', $file;
     print $fh <<EOF;
 package $module\::Install::Files;
+use strict;
+use warnings;
 require $module;
 sub Inline { shift; $module->Inline(\@_) }
 1;
@@ -438,7 +440,7 @@ sub ACTION_alien_code {
   my $cabinet = Alien::Base::ModuleBuild::Cabinet->new;
 
   foreach my $repo (@repos) {
-    $cabinet->add_files( $repo->probe() );
+    $cabinet->add_files( $repo->probe );
   }
 
   $cabinet->sort_files;
@@ -961,7 +963,7 @@ sub do_system {
   # restore wd
   $CWD = $initial_cwd;
 
-  return wantarray ? %return : $return{success};  ## no critic (Policy::Freenode::Wantarray)
+  return wantarray ? %return : $return{success};  ## no critic (Policy::Community::Wantarray)
 }
 
 sub _alien_execute_helper {
@@ -1276,6 +1278,21 @@ sub _catdir {
   $dir;
 }
 
+sub alien_install_network {
+  defined $ENV{ALIEN_INSTALL_NETWORK} ? !!$ENV{ALIEN_INSTALL_NETWORK} : 1;
+}
+
+sub alien_download_rule {
+
+  if(defined $ENV{ALIEN_DOWNLOAD_RULE}) {
+    return 'warn' if $ENV{ALIEN_DOWNLOAD_RULE} eq 'default';
+    return $ENV{ALIEN_DOWNLOAD_RULE} if $ENV{ALIEN_DOWNLOAD_RULE} =~ /^(warn|digest|encrypt|digest_or_encrypt|digest_and_encrypt)$/;
+    warn "unknown ALIEN_DOWNLOAD_RULE \"ALIEN_DOWNLOAD_RULE\", using \"warn\" instead";
+  }
+
+  return 'warn';
+}
+
 1;
 
 =pod
@@ -1288,7 +1305,7 @@ Alien::Base::ModuleBuild - A Module::Build subclass for building Alien:: modules
 
 =head1 VERSION
 
-version 1.09_01
+version 1.16_01
 
 =head1 SYNOPSIS
 
@@ -1446,6 +1463,21 @@ Executes the commands for the given phase.
 
 Takes the input string and interpolates the results.
 
+=head2 alien_install_network
+
+ my $bool = $amb->alien_install_network;
+
+Returns true if downloading source from the internet is allowed.  This
+is true unless C<ALIEN_INSTALL_NETWORK> is defined and false.
+
+=head2 alien_download_rule
+
+ my $rule = $amb->alien_download_rule;
+
+This will return one of C<warn>, C<digest>, C<encrypt>, C<digest_or_encrypt>
+or C<digest_and_encrypt>.  This is based on the C<ALIEN_DOWNLOAD_RULE>
+environment variable.
+
 =head1 GUIDE TO DOCUMENTATION
 
 The documentation for C<Module::Build> is broken up into sections:
@@ -1489,22 +1521,62 @@ in C<Module::Build::API>.
 
 =over 4
 
-=item B<ALIEN_VERBOSE>
+=item B<ALIEN_ARCH>
 
-Enables verbose output from L<M::B::do_system|Module::Build#do_system>.
+Set to a true value to install to an arch-specific directory.
+
+=item B<ALIEN_DOWNLOAD_RULE>
+
+This controls security options for fetching alienized packages over the internet.
+The legal values are:
+
+=over 4
+
+=item C<warn>
+
+Warn if the package is either unencrypted or lacks a digest.  This is currently
+the default, but will change in the near future.
+
+=item C<digest>
+
+Fetch will not happen unless there is a digest for the alienized package.
+
+=item C<encrypt>
+
+Fetch will not happen unless via an encrypted protocol like C<https>, or if the
+package is bundled with the L<Alien>.
+
+=item C<digest_or_encrypt>
+
+Fetch will only happen if the alienized package has a cryptographic signature digest,
+or if an encrypted protocol like C<https> is used, or if the package is bundled with
+the L<Alien>.  This will be the default in the near future.
+
+=item C<digest_and_encrypt>
+
+Fetch will only happen if the alienized package has a cryptographic signature digest,
+and is fetched via a secure protocol (like C<https>).  Bundled packages are also
+considered fetch via a secure protocol, but will still require a digest.
+
+=back
 
 =item B<ALIEN_FORCE>
 
 Skips checking for an installed version and forces reinstalling the Alien target.
 
+=item B<ALIEN_INSTALL_NETWORK>
+
+If true (the default if not defined), then network installs will be allowed.
+Set to C<0> or another false value to turn off network installs.
+
 =item B<ALIEN_INSTALL_TYPE>
 
 Set to 'share' or 'system' to override the install type.  Set to 'default' or unset
 to restore the default.
 
-=item B<ALIEN_ARCH>
+=item B<ALIEN_VERBOSE>
 
-Set to a true value to install to an arch-specific directory.
+Enables verbose output from L<M::B::do_system|Module::Build#do_system>.
 
 =item B<ALIEN_${MODULENAME}_REPO_${PROTOCOL}_${KEY}>
 
@@ -1587,13 +1659,13 @@ Kang-min Liu (劉康民, gugod)
 
 Nicholas Shipp (nshp)
 
-Petr Pisar (ppisar)
+Petr Písař (ppisar)
 
 Alberto Simões (ambs)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012-2020 by Joel A Berger.
+This software is copyright (c) 2012-2022 by Joel A Berger.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
