@@ -2,14 +2,17 @@ package Alien::Base::ModuleBuild::Repository::FTP;
 
 use strict;
 use warnings;
-
-our $VERSION = '1.08';
-
 use parent 'Alien::Base::ModuleBuild::Repository';
-
 use Carp;
 use Net::FTP;
 
+# ABSTRACT: HTTP repository handler
+our $VERSION = '1.16_01'; # TRIAL VERSION
+$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+
+sub is_network_fetch { 1 }
+sub is_secure_fetch  { 0 }
+
 sub connection {
   my $self = shift;
 
@@ -65,11 +68,11 @@ __END__
 
 =head1 NAME
 
-Alien::Base::ModuleBuild::Repository::FTP
+Alien::Base::ModuleBuild::Repository::FTP - HTTP repository handler
 
 =head1 VERSION
 
-version 1.09_01
+version 1.16_01
 
 =head1 AUTHOR
 
@@ -107,13 +110,13 @@ Kang-min Liu (劉康民, gugod)
 
 Nicholas Shipp (nshp)
 
-Petr Pisar (ppisar)
+Petr Písař (ppisar)
 
 Alberto Simões (ambs)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012-2020 by Joel A Berger.
+This software is copyright (c) 2012-2022 by Joel A Berger.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
