@@ -9,9 +9,12 @@ use Path::Tiny qw( path );
 use parent 'Alien::Base::ModuleBuild::Repository';
 
 # ABSTRACT: Local file repository handler
-our $VERSION = '1.09_01'; # TRIAL VERSION
+our $VERSION = '1.16_01'; # TRIAL VERSION
 $VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
+sub is_network_fetch { 0 }
+sub is_secure_fetch  { 1 }
+
 sub new {
   my $class = shift;
 
@@ -66,7 +69,7 @@ Alien::Base::ModuleBuild::Repository::Local - Local file repository handler
 
 =head1 VERSION
 
-version 1.09_01
+version 1.16_01
 
 =head1 AUTHOR
 
@@ -104,13 +107,13 @@ Kang-min Liu (劉康民, gugod)
 
 Nicholas Shipp (nshp)
 
-Petr Pisar (ppisar)
+Petr Písař (ppisar)
 
 Alberto Simões (ambs)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012-2020 by Joel A Berger.
+This software is copyright (c) 2012-2022 by Joel A Berger.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
