@@ -6,7 +6,7 @@ use Text::Balanced qw/extract_bracketed extract_delimited extract_multiple/;
 use parent 'Exporter';
 
 # ABSTRACT: Private utilities
-our $VERSION = '1.09_01'; # TRIAL VERSION
+our $VERSION = '1.16_01'; # TRIAL VERSION
 $VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 our @EXPORT_OK = qw/find_anchor_targets pattern_has_capture_groups/;
@@ -64,7 +64,7 @@ Alien::Base::ModuleBuild::Utils - Private utilities
 
 =head1 VERSION
 
-version 1.09_01
+version 1.16_01
 
 =head1 AUTHOR
 
@@ -102,13 +102,13 @@ Kang-min Liu (劉康民, gugod)
 
 Nicholas Shipp (nshp)
 
-Petr Pisar (ppisar)
+Petr Písař (ppisar)
 
 Alberto Simões (ambs)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012-2020 by Joel A Berger.
+This software is copyright (c) 2012-2022 by Joel A Berger.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
